==> clc_msa_utils-0.11.2.tar.gz: clc_msa_utils-0.11.2/clc_msa_utils/log_manager.py <==
import logging


class LogManager:
    _DEFAULT_LOG_FORMAT = "[%(threadName)s] %(asctime)s - %(levelname)s - %(name)s - %(message)s"
    _DEFAULT_DATE_FORMAT = "%m/%d/%Y %I:%M:%S %p"

    def __init__(self,
                 kv_store):
        self._logger = logging.getLogger("LogManager")
        self._kv_store = kv_store
        logging.basicConfig(format=self._DEFAULT_LOG_FORMAT)
        self._logger.setLevel(logging.DEBUG)
        self._configure_logging(None, kv_store.get_dict(default={}))
        self._logger.setLevel(logging.INFO)
        self._kv_store.on_reload(self._configure_logging)

    def _configure_logging(self, old_config, new_config):
        self._logger.debug("BEGIN _configure_logging")

        if not old_config or not old_config == new_config:
            self._logger.debug("Configuration changed, configuring logging...")
            # Basic configuration
            basic_config = {
                "filename": new_config.get('logging_filename'),
                "filemode": new_config.get('logging_filemode'),
                "format": new_config.get('logging_format', self._DEFAULT_LOG_FORMAT),
                "datefmt": new_config.get('logging_datefmt', self._DEFAULT_DATE_FORMAT),
                "level": logging.INFO
            }
            try:
                if 'logging_level' in new_config:
                    numeric_level = getattr(logging, new_config.get('logging_level'))
                    basic_config['level'] = numeric_level
                    logging.getLogger('').setLevel(numeric_level)
                else:
                    logging.getLogger('').setLevel(logging.INFO)
            except:
                self._logger.warning("Invalid level, {1}, for root logging configuration."
                                     .format("logging_level", new_config.get('logging_level')))

            self._logger.debug("Setting base configuration to {0}"
                               .format(str(basic_config)))
            logging.basicConfig(**basic_config)

            # Specific logger configuration
            if 'logging_config' in new_config and type(new_config.get('logging_config')) is dict:
                self._logger.debug("logging_config found.")
                logging_config = new_config.get('logging_config')

                for log_name in new_config.get('logging_config'):
                    logger = logging.getLogger(log_name)
                    current_logging_config = logging_config.get(log_name)
                    self._logger.debug("Configuration for {0} is {1}.".format(log_name, str(current_logging_config)))

                    if type(current_logging_config) is str:
                        self._logger.debug("Configuring logger for {0}..."
                                           .format(log_name))
                        try:
                            numeric_level = getattr(logging, current_logging_config)
                            self._logger.debug("Configuring logging level to {0} for {1}..."
                                               .format(str(numeric_level), log_name))
                            logger.setLevel(numeric_level)
                        except:
                            self._logger.warning("Invalid level, {1}, for {0} logging configuration."
                                                 .format(log_name, current_logging_config))

            else:
                self._logger.debug("logging_config NOT found.")

        else:
            self._logger.debug("Configuration unchanged.")
        self._logger.debug("END _configure_logging")

==> clc_msa_utils-0.13.0b2.tar.gz: clc_msa_utils-0.13.0b2/clc_msa_utils/log_manager.py <==
import logging
import datetime
import json_log_formatter

class CustomisedJSONFormatter(json_log_formatter.JSONFormatter):
    def json_record(self, message: str, extra: dict, record: logging.LogRecord) -> dict:
        extra['message'] = message

        # Include builtins
        extra['severity'] = record.levelname
        extra['source'] = record.name
        extra['pathname'] = record.pathname
        extra['lineno'] = record.lineno
        extra['func'] = record.funcName

        if 'time' not in extra:
            extra['time'] = datetime.datetime.utcnow()
        if record.exc_info:
            extra['exc_info'] = self.formatException(record.exc_info)

        return extra

formatter = CustomisedJSONFormatter()
json_handler = logging.FileHandler("/dev/stdout")
json_handler.setFormatter(formatter)

# This redirects warnings to be logged, so that they are logged as json with the correct warning severity
# However, warnings that are captured by other means may need to turn this off before hand (and then back on afterwards)
logging.captureWarnings(True)
logger = logging.getLogger()
logger.addHandler(json_handler)
logger.setLevel(logging.INFO)

class LogManager:
    def __init__(self,
                 kv_store):
        # logger for this class
        self._logger = logging.getLogger("LogManager")

        self._kv_store = kv_store
        self._configure_logging(None, kv_store.get_dict(default={}))
        self._kv_store.on_reload(self._configure_logging)

    def _configure_logging(self, old_config, new_config):
        self._logger.debug("BEGIN _configure_logging")

        if not old_config or not old_config == new_config:
            self._logger.debug("Configuration changed, configuring logging...")
            logger = logging.getLogger()
            try:
                if 'logging_level' in new_config:
                    numeric_level = getattr(logging, new_config.get('logging_level'))
                    logger.setLevel(numeric_level)
                else:
                    logger.setLevel(logging.INFO)
            except:
                self._logger.warning("Invalid level, {1}, for root logging configuration."
                                     .format("logging_level", new_config.get('logging_level')))

            # Specific logger configuration
            if 'logging_config' in new_config and type(new_config.get('logging_config')) is dict:
                self._logger.debug("logging_config found.")
                logging_config = new_config.get('logging_config')

                for log_name in logging_config:
                    logger = logging.getLogger(log_name)
                    current_logging_config = logging_config.get(log_name)
                    self._logger.debug("Configuration for {0} is {1}.".format(log_name, str(current_logging_config)))

                    if type(current_logging_config) is str:
                        self._logger.debug("Configuring logger for {0}..."
                                           .format(log_name))
                        try:
                            numeric_level = getattr(logging, current_logging_config)
                            self._logger.debug("Configuring logging level to {0} for {1}..."
                                               .format(str(numeric_level), log_name))
                            logger.setLevel(numeric_level)
                        except:
                            self._logger.warning("Invalid level, {1}, for {0} logging configuration."
                                                 .format(log_name, current_logging_config))
            else:
                self._logger.debug("logging_config NOT found.")
        else:
            self._logger.debug("Configuration unchanged.")
        self._logger.debug("END _configure_logging")
